@@ -273,8 +273,13 @@ class Q_Bloque_grafica:
 
         self.fig.canvas.draw()        
 
-#Run the program
+
+
 if __name__ == '__main__':
     app = QApplication(sys.argv)
     window = Main_Window()
     sys.exit(app.exec())
+
+app = QApplication(sys.argv)
+window = Main_Window()
+sys.exit(app.exec())
\ No newline at end of file
